Discover Packages
github.com/allisonhere/tide
internal
opml
package
Version:
v1.0.16
Opens a new window with list of versions in this module.
Published: May 15, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Body struct {
Outlines []Outline `xml:"outline"`
}
type Head struct {
Title string `xml:"title"`
DateCreated string `xml:"dateCreated,omitempty"`
}
type OPML struct {
XMLName xml .Name `xml:"opml"`
Version string `xml:"version,attr"`
Head Head `xml:"head"`
Body Body `xml:"body"`
}
type Outline struct {
Text string `xml:"text,attr"`
Title string `xml:"title,attr,omitempty"`
Type string `xml:"type,attr,omitempty"`
XMLURL string `xml:"xmlUrl,attr,omitempty"`
HTMLURL string `xml:"htmlUrl,attr,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.